pythermica package
==================

Submodules
----------

pythermica.analyse\_nwk module
------------------------------

.. automodule:: pythermica.analyse_nwk
   :members:
   :undoc-members:
   :show-inheritance:

pythermica.hdf5\_process module
-------------------------------

.. automodule:: pythermica.hdf5_process
   :members:
   :undoc-members:
   :show-inheritance:

pythermica.plot\_variables module
---------------------------------

.. automodule:: pythermica.plot_variables
   :members:
   :undoc-members:
   :show-inheritance:

pythermica.pythermica module
----------------------------

.. automodule:: pythermica.pythermica
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pythermica
   :members:
   :undoc-members:
   :show-inheritance:
